=====================
Keycloak Django Utils
=====================


.. image:: https://img.shields.io/pypi/v/keycloak_django_utils.svg
        :target: https://pypi.python.org/pypi/keycloak_django_utils

.. image:: https://img.shields.io/travis/lucas8107/keycloak_django_utils.svg
        :target: https://travis-ci.com/lucas8107/keycloak_django_utils

.. image:: https://readthedocs.org/projects/keycloak-django-utils/badge/?version=latest
        :target: https://keycloak-django-utils.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://keycloak-django-utils.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
